#Appication & Implications
This week is about proposing a final project, defining the scope of the project and developing a project plan.

### Page Summary
1. Scope
2. Project Proposal
3. Project Plan
4. Important and interesting links
---

1. Defining the scope  
---
**About vertical farming**  
Vertical farming is the practice of food production that takes the form of vertically stacked layers and vertically inclined surfaces. The method is executed inside a controlled environment setting, usually without soil or natural light.

Also known as indoor farming, vertical farming has in recent years gained recognition as a solid method of sustainability. The system was born out of the challenges affecting the 21st century, specifically issues like food shortage, resource depletion, and overpopulation.  
Controlled Environment Agriculture (CEA) is an advanced and intensive form of hydroponically-based agriculture where plants grow within a controlled environment to optimise horticultural practices. Environmental conditions can be easily regulated to encourage the growth of plants.  

**Benefits of CEA:**  
1\. Grow more than one type of plant simultaneously without taking up much space   
2\. Less water than conventional horizontal farming  
3\. More crops in the same times (when done at scale)  
4\. Controlled environment - not season dependant  
5\. Reduced distance between food production and consumption  
6\. Closer to self-sustainability if system done correctly  

**Cons:**  
1\. Energy consumption is high  
2\. Specialised equipment  
3\. Natural pollination not possible in a controlled environment  
4\. Technology dependancy  

While to make a viable business around vertical farming has many aspects like space optimisation, demand and supply rate, etc., in this project I want to concentrate on the technical aspects and make them modifiable when scaled to make a bigger farm.  
Decisions to make successful growing:  
1\. Crop selection   
2\. Lighting selection  
3\. Data, sensors, control and software  
4\. Substrate selection  
5\. Spacing of crops  
6\. Temperature and humidity  

2. Project Proposal
---
**What will it do?**  
Controlled environment vertical farming has in recent years gained recognition as a solid method of sustainability. The system was born out of the challenges affecting the 21st century, specifically issues like food shortage, resource depletion, and overpopulation. The Covid-19 pandemic has also proven the need for self-sustainability and low-km supply chains, which is inherently offered by indoor farming practices.  
My final project is a machine/tool for home experimentation of indoor farming. The machine's purpose is to bridge the gap between large scale production and home practices. Therefore I will try to make all environmental conditions controllable by the user, so they can experiment, record and figure out what works best for different types of plants in different conditions. This machine will be a tool to prototype ideal conditions before scaling for larger production.  

**Who's done what beforehand?**  
I started by learning what work is already done. Both, for the overall project as well as systems in parts.  
There are many commercially available hydroponic growing systems.
Some particular ones I like are:
The modularity and the ease-of-use in the [Moltkegarden](https://moltkegarden.com/) project.  
[True garden](https://truegarden.com/residential/) has extensive information and how-tos for starting a vertical garden.  
[FARM-X: The First Modular Vertical Farm Concept (Almost) Unveiled](http://www.conceptualdevices.com/2015/03/farm-x-the-first-modular-vertical-farm-concept-unveiled-almost/)  
This [Modular Vertical Farming projects](https://hackaday.io/project/5084-modular-vertical-farming) has an interesting approach to designing a scalable system.  
A common project using DHT11 and OLED display to make a [Weather station](https://create.arduino.cc/projecthub/herolivechannel/weather-station-arduino-dht11-sensor-oled-display-2f8e50).  
And the best reference for everything from a product to a system to developing a community and a business model - [Aquapioneers: business integrating product and services for aquaponic farming](http://aquapioneers.io/)   
There are many [generic products](https://www.amazon.com/s?k=hydroponic+planters+for+indoor+plants&crid=3MV6Q4GAC2WCG&sprefix=hydroponic+planter%2Caps%2C518&ref=nb_sb_ss_ts-doa-p_1_18) available in the market as well.

![generic products in market](./images/final-project/generic.png)  


**What will you design?**   
I will make all fabricate-able parts individually using different processes and integrate all them cohesively.  
1. A phototransistor to sense daylight intensity and change brightness of the LED growlight accordingly.  
2. A temperature and humidity sensor to measure and display values on an OLED screen.  
3. Power schematic with 12V DC, 5V DC converted from AC.  
4. Submersible water pump attached to spray heads to spray the roots of plants.
3. Use regulators to control the water flow and light intensity.
5. Acrylic body using laser cut joints, no fasteners and waterproof the tank with silicon sealant.  
6. Laser-cut porous pots to hold the growth medium and the plants  
7. Growing seedlings of plants and then putting them in the rockwool to grow more.  
8. Designing the PCB and fabricating it, soldering on components, programming the board and testing inputs/outputs  
9. Making a 3D model for planning and extracting 2D cutting files.  
10. 3D printing parts - the regulator knobs and some joints if required   

**What materials and components will be used? What parts and systems will be made?**   
The main body of the machine is made from 3mm acrylic in a frost white finish. Acrylic is not reactive to water, it can be laser cut easily accurately and joints can be waterproof using silicon sealant.
It doesn't react to the nutrient solution in the reservoir.
It can be joined without using any fasteners.

I used a FR1 single sided copper sheet to mill the circuit. I then gathered all components and electrical parts from the FabLab UAE's stock of materials.  
I also repurposed a 12V DC water pump from an old project lying around in the lab.
I ordered A SSD1306 OLED screen with I2C, a generic sprinkler system, some spinach seedlings and the nutrient solution online.   

The major parts of the machine are the body and the net pots, the pump and sprinkler system, the electronics including the inputs/outputs, the PCB and wires.  


**Where will come from? How much will they cost?**   
I have added all sources and costs of all materials used in the project in this [Bill of Materials File](./images/final-project/v7.bom.xlsx.zip).  

![Bill of Materials](./images/final-project/bom.jpg)  

**What processes will be used?**  
Parts of the machine will incorporate 2D and 3D design, additive and subtractive fabrication processes, electronics design and production, embedded microcontroller interfacing and programming, system integration and packaging.  
**CAD** - make 2D for cutting/production files & make a 3D model to plan, animate and render  
**Inputs** -  sensors to measure temperature, humidity and, switches to power and regulators to control  
**Output** -  LED growth lights, water pump and OLED screen to display conditions.   
**CAM** - laser cut all parts, use vinyl cutter for labelling something...    
**3D printing** - additive manufacture for some joints, make regulator knobs or parts of the sprinkler system...  
**Electronic design, production and embedded programming** - To make the microcontoller     
**Network and Communication** - Add WiFi module to control it remotely?  (maybe in later spirals)  
**Interface and Application programming** - To make a GUI (phone app?)  (maybe in later spirals)  

**What questions need to be answered?**  
My initial questions during the process were:  
1. How to choose the right microcontroller?  
2. How do the readings on the sensors translate to physical properties?   
3. How does PWM work? Will it help in regulating the pump and the light?  
4. What are the different techniques of aeroponics? Which is ideal for this machine?  
5. If I add a wifi-module later on, do I need to change the microcontroller?  

**How will it be evaluated?**  
The best way to evaluate the project is to successfully grow a plant in it. I made spinach seedlings from seeds and have put them in the machine to grow further. The success will depend on the right temperature, humidity and light conditions.  

Here is a picture of the seedlings growing inside the system.  
![growing](./images/final-project/trial.png)       

# 3. Project Plan
---
![Spiral Development Plan](./images/final-project/spiral.jpg)    

I will start by prototyping simple individual systems independently first, and then step-by-step add complexity and merge them.  
1. Arduino Uno + DHT11 serial read **>** add OLED display **>** replace Arduino Uno with ATtiny44 **>** add tiny libraries **>** add custom fonts  
2. Arduino Uno + phototransistor **>** Arduino Uno +  LED strip **>** add potentiometer to control brightness **>** replace Arduino Uno with ATtiny44 with n-mosfet **>** add tiny libraries  
3. Arduino Uno +  water pump **>** add potentiometer to control water flow **>** replace Arduino Uno with ATtiny44 with n-mosfet **>** add tiny libraries  
Like so, I eventually merge all systems into a single code and try to integrate it.  

3. Important and interesting links
---
I listed out the inputs and outputs to include in the design after studying some similar projects like [POWAR](http://www.pablozuloaga.com/POWAR.html), [Mixoponics](https://fab.academany.org/2020/labs/bahrain/students/muhja-aljaser/projects/final-project/), etc.  
A common project using DHT11 and OLED display is to make a [Weather station](https://create.arduino.cc/projecthub/herolivechannel/weather-station-arduino-dht11-sensor-oled-display-2f8e50).  
And the best reference for everything from a product to a system to developing a community and a business model - [Aquapioneers: business integrating product and services for aquaponic farming](http://aquapioneers.io/)
